yt.analysis_modules.halo_finding.halo_objects.LoadedHaloList.write_particle_lists_txt — The yt Project 3.2-dev documentation

# yt.analysis_modules.halo_finding.halo_objects.LoadedHaloList.write_particle_lists_txt

`LoadedHaloList.` `write_particle_lists_txt`(prefix, fp=None)

  Write out the names of the HDF5 files containing halo particle data to a text file. Needed in particular for parallel analysis output.

  Parameters: | prefix : String The prefix for the name of the file.

  Examples

      >>> halos.write_particle_lists_txt("halo-parts")